@@ -1,3 +1,9 @@
+"""The SoCo-CLI API
+
+Provides a few simple, high-level functions that allow the features of SoCo-CLI
+to be used in other programs.
+"""
+
 import logging
 import sys
 from io import StringIO
@@ -5,9 +11,9 @@ from signal import SIGINT, signal
 
 from soco import SoCo
 
-from .action_processor import process_action
-from .speakers import Speakers
-from .utils import (
+from soco_cli.action_processor import process_action
+from soco_cli.speakers import Speakers
+from soco_cli.utils import (
     configure_logging,
     create_speaker_cache,
     get_speaker,
@@ -25,14 +31,17 @@ def run_command(speaker_name, action, *args, use_local_speaker_list=False):
     three-tuple. If the exit code is non-zero, the error message will be
     populated and the output string will always be empty.
 
-    :param speaker_name: The name of the speaker, or its IP address, as
-        a string
-    :param action: The name of the SoCo-CLI action to perform, as a string
-    :param args: The list of arguments (strings) for the action. Each argument
-        is a string. Arguments are optional depending on the action.
-    :param use_local_speaker_list: Whether to use the local speaker
-        cache to map the speaker name into an IP address. Bool.
-    :return: Three-tuple (exit_code, output_string, error_msg)
+    All exceptions are caught when this function is run. Exception details
+    will be returned in the error message string.
+
+    Args:
+        speaker_name (str): The name of the speaker, or its IP address
+        action (str): The The name of the SoCo-CLI action to perform
+        *args (list[str]): The set of arguments that accompany the action
+
+    Returns:
+        int, str, str: a three-tuple of exit_code, output_string and
+        error_msg.
     """
 
     # Prevent errors from causing exit
@@ -45,15 +54,13 @@ def run_command(speaker_name, action, *args, use_local_speaker_list=False):
     sys.stderr = error
 
     speaker = None
-
     exception_error = None
 
     # Can pass a SoCo object instead of the speaker name (not documented)
-    if type(speaker_name) == SoCo:
+    if isinstance(speaker_name, SoCo):
         speaker = speaker_name
-        speaker_name = speaker.player_name
 
-    elif type(speaker_name) == str:
+    elif isinstance(speaker_name, str):
         try:
             speaker = _get_soco_object(
                 speaker_name, use_local_speaker_list=use_local_speaker_list
@@ -72,7 +79,6 @@ def run_command(speaker_name, action, *args, use_local_speaker_list=False):
         except Exception as e:
             logging.info("Exception: {}".format(e))
             exception_error = e
-            pass
 
         output_msg = output.getvalue().rstrip()
         error_out = error.getvalue().rstrip()
@@ -106,55 +112,53 @@ def run_command(speaker_name, action, *args, use_local_speaker_list=False):
 
 
 def set_log_level(log_level="None"):
-    """Convenience function to set up logging
+    """Convenience function to set up logging.
 
-    :param log_level: Can be one of None, Critical, Error, Warn, Info, Debug.
+    Args:
+        log_level (str): Can be one of None, Critical, Error, Warn, Info, Debug.
     """
     configure_logging(log_level)
 
 
 def handle_sigint():
-    """
-    Convenience function to set up a more graceful
-    CTRL-C (sigint) handler.
-    """
+    """Convenience function to set up a more graceful CTRL-C (sigint) handler."""
     signal(SIGINT, sig_handler)
 
 
 def rescan_speakers():
-    """Run full network scan to find speakers"""
+    """Run full network scan to find speakers."""
     _check_for_speaker_cache()
     speaker_cache().scan(reset=True)
 
 
 def rediscover_speakers():
-    """Run normal SoCo discovery to discover speakers"""
+    """Run normal SoCo discovery to discover speakers."""
     _check_for_speaker_cache()
     speaker_cache().discover(reset=True)
 
 
 def get_all_speakers():
-    """Return all SoCo instances"""
+    """Return all SoCo instances."""
     _check_for_speaker_cache()
     return [s[0] for s in speaker_cache().get_all_speakers()]
 
 
 def get_all_speaker_names():
-    """Return all speaker names"""
+    """Return all speaker names."""
     _check_for_speaker_cache()
     return speaker_cache().get_all_speaker_names()
 
 
 def get_soco_object(speaker_name, use_local_speaker_list=False):
-    """
-    Uses the full set of soco_cli strategies to map a speaker name
-    into a SoCo object
+    """Uses the full set of soco_cli strategies to find a speaker.
 
-    :param speaker_name: The name of the speaker as a string
-    :param use_local_speaker_list: Whether to use the local speaker cache
+    Args:
+        speaker_name (str): The name of the speaker to find.
+        use_local_speaker_list (bool): Whether to use the local speaker cache.
 
-    :return Tuple of SoCo object, or None if no speaker is found, and an
-        error message.
+    Returns:
+        (SoCo, str): Tuple of SoCo object, or None if no speaker is found,
+        and an error message.
     """
     set_api()
 
@@ -173,7 +177,7 @@ def get_soco_object(speaker_name, use_local_speaker_list=False):
 
 
 def _get_soco_object(speaker_name, use_local_speaker_list=False):
-    """Internal helper version that doesn't redirect stderr"""
+    """Internal helper version that doesn't redirect stderr."""
 
     if use_local_speaker_list:
         _setup_local_speaker_list()
@@ -189,16 +193,16 @@ def _check_for_speaker_cache():
 
 
 # For local speaker list operations
-SPEAKER_LIST_SET = False
+speaker_list_set = False
 
 
 def _setup_local_speaker_list():
-    global SPEAKER_LIST_SET
-    if not SPEAKER_LIST_SET:
+    global speaker_list_set
+    if not speaker_list_set:
         speaker_list = Speakers()
         if not speaker_list.load():
             logging.info("Start speaker discovery")
             speaker_list.discover()
             speaker_list.save()
         set_speaker_list(speaker_list)
-    SPEAKER_LIST_SET = True
+    speaker_list_set = True
